@@ -5,7 +5,7 @@ import subprocess
 
 from ffmpeg import probe
 from tqdm import tqdm
-from utils import FileInfoProvider
+from .utils import FileInfoProvider
 
 
 class FfmpegProcess:
